Documentation
¶
Index ¶
- type CollectionData
- type ProcessPlanController
- func (c *ProcessPlanController) CreateProcessPlan(ctx *gin.Context)
- func (c *ProcessPlanController) DeleteProcessPlanbyID(ctx *gin.Context)
- func (c *ProcessPlanController) GetDetailCProcessPlanbyID(ctx *gin.Context)
- func (c *ProcessPlanController) GetListofProcessPlan(ctx *gin.Context)
- func (c *ProcessPlanController) UpdateCollectionData(ctx *gin.Context, collectionName string)
- func (c *ProcessPlanController) UpdateProcessPlan(ctx *gin.Context)
- func (c *ProcessPlanController) UpdateProcessPlanHistory(ctx *gin.Context)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CollectionData ¶
type ProcessPlanController ¶
type ProcessPlanController struct {
}
func (*ProcessPlanController) CreateProcessPlan ¶
func (c *ProcessPlanController) CreateProcessPlan(ctx *gin.Context)
UpdateCollectionData updates the collection data in the repository. It retrieves the user information from the request context and binds the JSON data. If the collection name is invalid, it returns an error response. If the data contains an "_id" field, it updates the collection with the specified ID. If the data does not contain an "_id" field, it inserts a new collection into the repository. The updated or inserted collection is then returned as a response.
func (*ProcessPlanController) DeleteProcessPlanbyID ¶
func (c *ProcessPlanController) DeleteProcessPlanbyID(ctx *gin.Context)
func (*ProcessPlanController) GetDetailCProcessPlanbyID ¶
func (c *ProcessPlanController) GetDetailCProcessPlanbyID(ctx *gin.Context)
func (*ProcessPlanController) GetListofProcessPlan ¶
func (c *ProcessPlanController) GetListofProcessPlan(ctx *gin.Context)
func (*ProcessPlanController) UpdateCollectionData ¶
func (c *ProcessPlanController) UpdateCollectionData(ctx *gin.Context, collectionName string)
func (*ProcessPlanController) UpdateProcessPlan ¶
func (c *ProcessPlanController) UpdateProcessPlan(ctx *gin.Context)
func (*ProcessPlanController) UpdateProcessPlanHistory ¶
func (c *ProcessPlanController) UpdateProcessPlanHistory(ctx *gin.Context)
Click to show internal directories.
Click to hide internal directories.